def install_vmdb2(ctx):
    srcdir = globals()["srcdir"]
    runcmd_prepend_to_path = globals()["runcmd_prepend_to_path"]
    runcmd_prepend_to_path(ctx, srcdir)
